# -*- coding: utf-8 -*-
from setuphelpers import *
import time, string, secrets
import platform

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

"""


if platform.system() == 'Windows':
    if uninstall_key_exists('RustDesk'):
        RustDeskBin = makepath(install_location('RustDesk'),'rustdesk.exe')
elif platform.system() == 'Darwin':
    RustDeskBin = "/Applications/RustDesk.app/Contents/MacOS/RustDesk"
else:
    RustDeskBin = "/usr/lib/rustdesk/rustdesk"

def install():

    rustdesk_cfg = open('rustdesk.cfg','r').read()

    alphabet = string.ascii_letters + string.digits
    rustdesk_pw = ''.join(secrets.choice(alphabet) for i in range(12))

    run_notfatal( '"%s" --config %s' % (RustDeskBin,rustdesk_cfg))
    run( '"%s" --password %s' % (RustDeskBin,rustdesk_pw ))

    if platform.system() == 'Windows':
        if service_is_running("rustdesk"):
            service_stop("rustdesk")
        service_start("rustdesk")

    elif platform.system() == 'Darwin':
        print('todo')
    else:
        systemd_restart_service('rustdesk')

def audit():

    rustdesk_id = run('"%s" --get-id' % RustDeskBin)

    if rustdesk_id.endswith('\n'):
        rustdesk_id = rustdesk_id.split('\n')[-2]

    alphabet = string.ascii_letters + string.digits
    rustdesk_pw = ''.join(secrets.choice(alphabet) for i in range(12))
    run( '"%s" --password %s' % (RustDeskBin,rustdesk_pw ))

    WAPT.write_audit_data_if_changed("rustdesk", 'rustdesk-id', rustdesk_id, max_count=365)
    WAPT.write_audit_data_if_changed("rustdesk", 'password_encryption', rsa_encrypted_data_str(rustdesk_pw, WAPT.public_certs_dir), max_count=365)
    
    return "OK"

def update_package():
    old_conf = ""
    if isfile('rustdesk.cfg'):
        old_conf = open('rustdesk.cfg','r').read()
        
    newconf = ""

    if not params.get("install_with_luti", False):
        import waptguihelper
        newconf = waptguihelper.memo_dialog('CFG RUSTDESK',"Please give your cfg config rustdesk",old_conf)

        control.package = control.package.replace('-template','')
        control.save_control_to_wapt()

    with open('rustdesk.cfg','w') as f:
        f.write(newconf)





